==> mumuzi-1.0.2.tar.gz: mumuzi-1.0.2/mumuzi/mumuzi/taoshenyulu.py <==
taoshenyulu=["mumuzi:\n\t你阳寿没了",
		"mumuzi:\n\t你阳寿阴寿都没了",
		"mumuzi:\n\t哈哈,大家聊了这么多啊,刚刚在厕所奖励了自己12个小时晕过去了,现在刚醒,看到群里发的涩图又得奖励自己了",
		"mumuzi:\n\t带我\nmumuzi:\n\t我是妹妹",
		"mumuzi:\n\t套起来",
		"mumuzi:\n\t我能怎么办嘛\nmumuzi:\n\t我总不能让大家一个个都去拜访出题人然后锤爆狗头",
		"mumuzi:\n\t实操 比 理论 有用",
		"mumuzi:\n\t撸出来的",
		"mumuzi:\n\t你要求真多",
		"mumuzi:\n\t也想玩女朋友",
		"mumuzi:\n\t要满了",
		"mumuzi:\n\t我躺好了你来吧\nmumuzi:\n\torz\nmumuzi:\n\t我就是很敏感的一个小女生\n\t\t\t呜呜",
		"mumuzi:\n\t干到我了",
		"mumuzi:\n\t就是你上了pornhub",
		"mumuzi:\n\t明天早点醒然后一把把手里屯的flag交上去,直接傍一震惊全场",
		"mumuzi:\n\t戴套干嘛",
		"mumuzi:\n\t麻了\nmumuzi:\n\t还要冲一次\nmumuzi\n\t退已经软了",
		"mumuzi:\n\t我这里 刚好有一个flag 我还不想交\nmumuzi:\n\t送你们交\nmumuzi:\n\t我flag还蛮多的 要是你们不介意的话 你们可以来我家要flag",
		"mumuzi:\n\t别想嫖我",
		"mumuzi:\n\t好热哦",
		"mumuzi:\n\t带什么带都滚去自己学去",
		"mumuzi:\n\t操",
		"mumuzi:\n\t你在哪",
		"mumuzi:\n\t来劲服务\nmumuzi:\n\t好",
		"mumuzi:\n\t一般",
		"mumuzi:\n\t但是神会",
		"mumuzi:\n\t8人！\nmumuzi:\n\t击剑！",
		"mumuzi:\n\t你猜八神这句话是不是我安排的",
		"mumuzi:\n\t我是傻逼",
		"mumuzi:\n\t榜一白上了",
		"mumuzi:\n\t狗群主狗管理,出来挨打！",
		"mumuzi:\n\t姐姐我要捏奶",
		"mumuzi:\n\t你买我就女装\nmumuzi:\n\t少说我也是穿过的",
		"mumuzi:\n\t等看了wp你就知道了\nmumuzi\n\t反正我写完了",
		"mumuzi:\n\t肾透可以",
		"mumuzi:\n\t要女师傅贴贴",
		"mumuzi:\n\t你进去啊",
		"mumuzi:\n\t搞就完了",
		"mumuzi:\n\t我刚刚都进了",
		"mumuzi:\n\t哦\nmumuzi:\n\t膨胀了\nmumuzi:\n\t已经开始",
		"mumuzi:\n\t做着方便",
		"mumuzi:\n\t你是不是不听话",
		"mumuzi:\n\t明白了,我套神要全部交完",
		"mumuzi:\n\t滚",
		"mumuzi:\n\t那么久了\nmumuzi:\n\t才操完？",
		"mumuzi:\n\t全是fw",
		"mumuzi:\n\t不仅面基,击剑都可以",
		"mumuzi:\n\t套神快爬啊",
		"mumuzi:\n\t以我现在的实力,一个小时应该能吧",
		"mumuzi:\n\t都是软的",
		"mumuzi:\n\t爬",
		"mumuzi:\n\t我想嫖",
		"mumuzi:\n\t不要射别人啊",
		"mumuzi:\n\t饭可以乱吃,话不可以乱说哦【刀】",
		"mumuzi:\n\t你是故意找茬是不是",
		"mumuzi:\n\t累啊【叹气】\nmumuzi:\n\t刚刚才冲了一次【叹气】",
		"mumuzi:\n\t老公操我",
		"mumuzi:\n\t自己捅一刀不好吗",
		"mumuzi:\n\t射射老板",
		"mumuzi:\n\t屯了两个月的flag",
		"mumuzi:\n\t我不套娃\nmumuzi:\n\t我不配套娃",
		"mumuzi:\n\t有点少哦",
		"mumuzi:\n\t叫你滚你都不滚",
		"mumuzi:\n\t废物",
		"mumuzi:\n\t出了\nmumuzi:\n\t差撸下来了",
		"mumuzi:\n\t还是100\nmumuzi:\n\t之前也是100 弄了3次而已",
		"mumuzi:\n\t死的安详一点嗷",
		"mumuzi:\n\t烦死了",
		"mumuzi:\n\t呃,嗯嗯,啊啊啊啊啊啊啊啊啊啊啊啊啊啊",
		"mumuzi:\n\t大佬来了",
		"L:\n\t这个二维码怎么识别啊\nmumuzi:\n\t肉眼",
		"mumuzi:\n\t就要这样",
		"mumuzi:\n\t进去了\nmumuzi:\n\t但没有完全进去",
		"mumuzi:\n\t笑死",
		"mumuzi:\n\t没擦干净",
		"mumuzi:\n\t我好寂寞啊",
		"mumuzi:\n\t我不要钱",
		"mumuzi:\n\t这是为了用的更方便",
		"mumuzi:\n\t@需要迅雷会员联系我无偿借 你群名笑死了\n需要迅雷会员联系我无偿借:\n\t笑nm",
		"mumuzi:\n\t老板断气\nmumuzi:\n\t老板身体欠刚",
		"mumuzi:\n\t我觉得我就肾虚",
		"mumuzi:\n\t恶不恶心",
		"mumuzi:\n\ttm给你来一刀",
		"mumuzi:\n\t叔叔我呀,最喜欢了",
		"mumuzi:\n\t只要协商好了 499个人一起都可以",
		"mumuzi:\n\t死",
		"mumuzi:\n\t自己买女装出去过过瘾\nmumuzi:\n\t然后卖出去\nmumuzi:\n\t还赚",
		"生产队:\n\t就是那个。两个圆圆的\n生产队:\n\t一根长长的,向上的\nmumuzi:\n\t当时晚上那个是你？",
		"mumuzi:\n\t挺好的\nmumuzi:\n\t他让我【马赛克】性开放了300%\nmumuzi:\n\t爱死了\nmumuzi:\n\t【狗头】\nmumuzi:\n\t不知道怎么说\nmumuzi:\n\t反正\nmumuzi:\n\t牛逼",
		"mumuzi:\n\t三等功竟是我自己\nmumuzi:\n\t【马桶感叹号】",
		"mumuzi:\n\tmumuzi:三等功到手了",
		"mumuzi:\n\t[cheyenne 17:33      ⬆]\n\t我这么拍套神马屁套神都不理我\n\t@cheyenne ?\nmumuzi:\n\ttm说话文明点",
		"mumuzi:\n\t我肾虚我牛逼",
		"mumuzi:\n\t我取证都是上门要flag的",
		"mumuzi:\n\t会打CTF,会挖洞,长得帅,还有女朋友",
		"mumuzi:\n\t我DNA动了",
		"衾曦:\n\t@mumuzi 今夜你是我的,谁也别想抢【可爱】【可爱】【可爱】\nmumuzi:\n\t好",
		"mumuzi:\n\t能让你做出来就不错了",
		"mumuzi:\n\t明白了,我【马赛克】神要全部交完",
		"mumuzi:\n\t确实\nmumuzi:\n\t尤其是套套子",
		"mumuzi:\n\t手都累死了",
		"mumuzi:\n\t是想告诉大家不要不识抬举",
		"mumuzi:\n\t你做爱",
		"mumuzi:\n\t我把wp发你 你去ak ctfshow吧 orz orz orz",
		"mumuzi:\n\t那是你菜",
		"mumuzi:\n\t现在越来越奇怪了",
		"Tokeii:\n\t鸡巴毛都看不见\nTokeii:\n\t到底有多大\nmumuzi:\n\t我7cm",
		"mumuzi:\n\t透我",
		"mumuzi:\n\t直接就能插的",
		"mumuzi:\n\t出不来题就不要出。",
		"mumuzi:\n\t那我不当人了",
		"mumuzi:\n\tPC还真不怎么用",
		"mumuzi:\n\t拿到这种我一般直接冲",
		"mumuzi:\n\t套神用食指和F5把平台DDOS了",
		"mumuzi:\n\t那我真大吗？"
		]

==> mumuzi-1.1.3.tar.gz: mumuzi-1.1.3/mumuzi/mumuzi/taoshenyulu.py <==
#v1.0.3更新顺序， 0-22为夸人专用回复
#v1.0.5修复部分错别字
#v1.1.3给群友打码
taoshenyulu=["mumuzi:\n\t你阳寿没了",
		"mumuzi:\n\t你阳寿阴寿都没了",
		"mumuzi:\n\t你要求真多",
		"mumuzi:\n\t爬",
		"mumuzi:\n\t废物",
		"mumuzi:\n\t死的安详一点嗷",
		"mumuzi:\n\t烦死了",
		"mumuzi:\n\t叫你滚你都不滚",
		"mumuzi:\n\t恶不恶心",
		"mumuzi:\n\ttm给你来一刀",
		"mumuzi:\n\t别想嫖我",
		"mumuzi:\n\t操",
		"mumuzi:\n\t你是不是不听话",
		"mumuzi:\n\t滚",
		"mumuzi:\n\t射射老板",
		"mumuzi:\n\t笑死",
		"mumuzi:\n\t就要这样",
		"mumuzi:\n\t进去了\nmumuzi:\n\t但没有完全进去",
		"mumuzi:\n\t是想告诉大家不要不识抬举",
		"mumuzi:\n\t那是你菜",
		"mumuzi:\n\t套起来",
		"mumuzi:\n\t一般",
		"mumuzi:\n\t来劲服务\nmumuzi:\n\t好",


		"mumuzi:\n\t哈哈,大家聊了这么多啊,刚刚在厕所奖励了自己12个小时晕过去了,现在刚醒,看到群里发的涩图又得奖励自己了",
		"mumuzi:\n\t带我\nmumuzi:\n\t我是妹妹",
		"mumuzi:\n\t我能怎么办嘛\nmumuzi:\n\t我总不能让大家一个个都去拜访出题人然后锤爆狗头",
		"mumuzi:\n\t实操 比 理论 有用",
		"mumuzi:\n\t撸出来的",
		"mumuzi:\n\t也想玩女朋友",
		"mumuzi:\n\t要满了",
		"mumuzi:\n\t我躺好了你来吧\nmumuzi:\n\torz\nmumuzi:\n\t我就是很敏感的一个小女生\n\t\t\t呜呜",
		"mumuzi:\n\t干到我了",
		"mumuzi:\n\t就是你上了pornhub",
		"mumuzi:\n\t明天早点醒然后一把把手里屯的flag交上去,直接傍一震惊全场",
		"mumuzi:\n\t戴套干嘛",
		"mumuzi:\n\t麻了\nmumuzi:\n\t还要冲一次\nmumuzi\n\t腿已经软了",
		"mumuzi:\n\t我这里 刚好有一个flag 我还不想交\nmumuzi:\n\t送你们交\nmumuzi:\n\t我flag还蛮多的 要是你们不介意的话 你们可以来我家要flag",
		"mumuzi:\n\t好热哦",
		"mumuzi:\n\t带什么带都滚去自己学去",
		"mumuzi:\n\t你在哪",
		"mumuzi:\n\t但是神会",
		"mumuzi:\n\t8人！\nmumuzi:\n\t击剑！",
		"mumuzi:\n\t你猜八神这句话是不是我安排的",
		"mumuzi:\n\t我是傻逼",
		"mumuzi:\n\t榜一白上了",
		"mumuzi:\n\t狗群主狗管理,出来挨打！",
		"mumuzi:\n\t姐姐我要捏奶",
		"mumuzi:\n\t你买我就女装\nmumuzi:\n\t少说我也是穿过的",
		"mumuzi:\n\t等看了wp你就知道了\nmumuzi\n\t反正我写完了",
		"mumuzi:\n\t肾透可以",
		"mumuzi:\n\t要女师傅贴贴",
		"mumuzi:\n\t你进去啊",
		"mumuzi:\n\t搞就完了",
		"mumuzi:\n\t我刚刚都进了",
		"mumuzi:\n\t哦\nmumuzi:\n\t膨胀了\nmumuzi:\n\t已经开始",
		"mumuzi:\n\t做着方便",
		"mumuzi:\n\t明白了,我套神要全部交完",
		"mumuzi:\n\t那么久了\nmumuzi:\n\t才操完？",
		"mumuzi:\n\t全是fw",
		"mumuzi:\n\t不仅面基,击剑都可以",
		"mumuzi:\n\t套神快爬啊",
		"mumuzi:\n\t以我现在的实力,一个小时应该能吧",
		"mumuzi:\n\t都是软的",
		"mumuzi:\n\t我想嫖",
		"mumuzi:\n\t不要射别人啊",
		"mumuzi:\n\t饭可以乱吃,话不可以乱说哦【刀】",
		"mumuzi:\n\t你是故意找茬是不是",
		"mumuzi:\n\t累啊【叹气】\nmumuzi:\n\t刚刚才冲了一次【叹气】",
		"mumuzi:\n\t老公操我",
		"mumuzi:\n\t自己捅一刀不好吗",
		"mumuzi:\n\t屯了两个月的flag",
		"mumuzi:\n\t我不套娃\nmumuzi:\n\t我不配套娃",
		"mumuzi:\n\t有点少哦",
		"mumuzi:\n\t出了\nmumuzi:\n\t差撸下来了",
		"mumuzi:\n\t还是100\nmumuzi:\n\t之前也是100 弄了3次而已",
		"mumuzi:\n\t呃,嗯嗯,啊啊啊啊啊啊啊啊啊啊啊啊啊啊",
		"mumuzi:\n\t大佬来了",
		"一般群友:\n\t这个二维码怎么识别啊\nmumuzi:\n\t肉眼",
		"mumuzi:\n\t没擦干净",
		"mumuzi:\n\t我好寂寞啊",
		"mumuzi:\n\t我不要钱",
		"mumuzi:\n\t这是为了用的更方便",
		"mumuzi:\n\t@需要迅雷会员联系我无偿借 你群名笑死了\n需要迅雷会员联系我无偿借:\n\t笑nm",
		"mumuzi:\n\t老板断气\nmumuzi:\n\t老板身体欠刚",
		"mumuzi:\n\t我觉得我就肾虚",
		"mumuzi:\n\t叔叔我呀,最喜欢了",
		"mumuzi:\n\t只要协商好了 499个人一起都可以",
		"mumuzi:\n\t自己买女装出去过过瘾\nmumuzi:\n\t然后卖出去\nmumuzi:\n\t还赚",
		"一般群友:\n\t就是那个。两个圆圆的\n一般群友:\n\t一根长长的,向上的\nmumuzi:\n\t当时晚上那个是你？",
		"mumuzi:\n\t挺好的\nmumuzi:\n\t他让我【马赛克】性开放了300%\nmumuzi:\n\t爱死了\nmumuzi:\n\t【狗头】\nmumuzi:\n\t不知道怎么说\nmumuzi:\n\t反正\nmumuzi:\n\t牛逼",
		"mumuzi:\n\t三等功竟是我自己\nmumuzi:\n\t【马桶感叹号】",
		"mumuzi:\n\tmumuzi:三等功到手了",
		"mumuzi:\n\t[一般群友 17:33      ⬆]\n\t我这么拍套神马屁套神都不理我\n\t@一般群友 ?\nmumuzi:\n\ttm说话文明点",
		"mumuzi:\n\t我肾虚我牛逼",
		"mumuzi:\n\t我取证都是上门要flag的",
		"mumuzi:\n\t会打CTF,会挖洞,长得帅,还有女朋友",
		"mumuzi:\n\t我DNA动了",
		"一般群友:\n\t@mumuzi 今夜你是我的,谁也别想抢【可爱】【可爱】【可爱】\nmumuzi:\n\t好",
		"mumuzi:\n\t能让你做出来就不错了",
		"mumuzi:\n\t明白了,我【马赛克】神要全部交完",
		"mumuzi:\n\t确实\nmumuzi:\n\t尤其是套套子",
		"mumuzi:\n\t手都累死了",
		"mumuzi:\n\t你做爱",
		"mumuzi:\n\t我把wp发你 你去ak ctfshow吧 orz orz orz",
		"mumuzi:\n\t现在越来越奇怪了",
		"一般群友:\n\t鸡巴毛都看不见\n一般群友:\n\t到底有多大\nmumuzi:\n\t我7cm",
		"mumuzi:\n\t透我",
		"mumuzi:\n\t直接就能插的",
		"mumuzi:\n\t出不来题就不要出。",
		"mumuzi:\n\t那我不当人了",
		"mumuzi:\n\tPC还真不怎么用",
		"mumuzi:\n\t拿到这种我一般直接冲",
		"mumuzi:\n\t套神用食指和F5把平台DDOS了",
		"mumuzi:\n\t那我真大吗？"
		]
